pub trait Logger: Send {
// Required methods
fn log_debug(&self, log_line: String);
fn log_error(&self, log_line: String);
fn log_info(&self, log_line: String);
fn log_trace(&self, log_line: String);
fn log_warn(&self, log_line: String);
}Expand description
Trait that can be used to forward Rust logs over FFI to a language specific logger.
Required Methods
Sourcefn log_debug(&self, log_line: String)
fn log_debug(&self, log_line: String)
Called every time the Rust side wants to post a debug log line.
Sourcefn log_error(&self, log_line: String)
fn log_error(&self, log_line: String)
Called every time the Rust side wants to post an error log line.
Sourcefn log_info(&self, log_line: String)
fn log_info(&self, log_line: String)
Called every time the Rust side wants to post an info log line.